<?php

require_once "fs_lang.php";
require_once "common_functions.php";
require_once 'generate_common.php';
require_once "..\\cfgmgr\\sysfunc.php";
require_once "..\\cfgmgr\\fsAPI.php";

// 20100428 - Moved from common_functions, add free_access_flag
// 20130624 - Skip check for expired self sign-up user
function fs_create_user($username, $password1, $password2, $timeleft, $sess_patronsoft2, $security, $free_access_flag, $scratch_code_flag)
{
	// return status (integer)
	// 0 - no problem, id successfully created
	// 1 - username cannot be empty
	// 2 - duplicated user id found in user database
	// 3 - password cannot be empty
	// 4 - 2 passwords did not match
	// 5 - restrict user to signup once and the user has signed up b4
	// 6 - user can only signup in a period of time and the last signup time is still in the self signup period
	// 7 - cannot get mac address
	// 9 - security code did not match
	// 10 - database not available
	// 11 - session cookies disabled
	$settingobj = new COM("FSCONFIG.Cfgmgr") or die("common_functions.php FSCONFIG.Cfgmgr Object cannot be created!");

	// 20090324 - Moved from below
	$self_signup_filter = $settingobj->getKey( "self_signup_filter", "gateway");

	$status		= 99;
	$create_id	= "yes";

	if ($username =="") {
		$status =1;
		$create_id="no";

	// 20090324 - Block signing-up without IP/MAC if enforced sign-up restriction
	} elseif ($self_signup_filter == 0 && $sess_patronsoft2 == "") {
		$status =7;
		$create_id="no";

	// 20100412 - Block no session cookies
	} elseif ($self_signup_filter == 1 && $sess_patronsoft2 == "") {
		$status = 11;
		$create_id = "no";

	} else {
		$q="SELECT count(*) as no FROM ".fs_usr_table()." where name='$username'";
		$result=db_query($q);

		// 20090402 - Add new return value for DB failure
		if ($result == FALSE) {
			$status		= 10;
			$create_id	= 'no';
		} else {
			$no = odbc_result($result, "no");

			$latest_signup_time = 0;

			// 20090324 - Check if sign-up restriction is on
			//if (not allow signup without) mac/ip OR (allow signup without mac/ip and the mac/ip is not null)
			if ($self_signup_filter == '0' && $sess_patronsoft2 != '') {
				$q		= "SELECT signuptime FROM ".fs_usr_table()." WHERE signupmac = '$sess_patronsoft2'";
				$rsut	= db_query($q);

				// 20090402 - Add new return value for DB failure
				if ($rsut == FALSE) {
					$status = 10;
					$create_id = 'no';
				} else {
					while (odbc_fetch_row($rsut)) {
						$self_signup_time = odbc_result($rsut, "signuptime");

						if ($self_signup_time > $latest_signup_time)
							$latest_signup_time = $self_signup_time;
					}
				}
			}
			$self_signup_period = $settingobj->getKey( "self_signup_period", "gateway");

			if (($no > 0) && ($username !="")) {
				$status =2;	//duplicated user id
				$create_id="no";
			// 20100428 - Bug fix (wrong condition check)
			} elseif ($password1 == "" && $password2 == "" && $username != "") {

				$status =3; //password not empty
				$create_id="no";

			// 20100428 - Bug fix (wrong condition check)
			} elseif (strcmp($password1, $password2) <> 0) {

				$status =4; //passwords did not match
				$create_id="no";
			}
			else if ($security == false){
				$status = 9;
			$create_id="no";
			}
			else if ($self_signup_filter == 0) {	//ip/mac filter is on
				if ($self_signup_period == 0) {	//only allow user to signup once
					// 20090402 - Ensure no DB failure in the previous query
					if ($create_id == 'yes' && $latest_signup_time != 0) {  //user has signed up b4 accordding to its mac/ip
						$status = 5;
						$create_id="no";
					}
				} else if ($self_signup_period > 0) { //allow user to signup again after x mins
					// 20090402 - Ensure no DB failure in the previous query
					if ($create_id == 'yes' && $latest_signup_time != 0) {  //user has signed up b4 accordding to its mac/ip
						$currentTime = mktime();
						$diff = $currentTime - ($latest_signup_time + $self_signup_period * 60);
						if ($diff < 0) {				//latest signup time is still in the self signup period
							$status = 6;
							$create_id="no";
						}//end if
					}//end if
				}//end else if
			}//end else if
		}
	}

	
	
	if ($create_id == "yes") {
		if ($timeleft == "")
			$timeleft="null";

		// 20100428 - Add account for free access user
		$now = mktime();
		$fields = array();
		$bFieldNumeric = array();
		$fields['timeleft'] = $timeleft;
		$bFieldNumeric['timeleft'] = 1;
		$fields['signupmac'] = $sess_patronsoft2;
		$bFieldNumeric['signupmac'] = 0;
		$fields['signuptime'] = $now;
		$bFieldNumeric['signuptime'] = 0;
		if ($free_access_flag) {
			$fields['macasusr'] = 'Y';
			$bFieldNumeric['macasusr'] = 0;
			$fields['faflag'] = 1;
			$bFieldNumeric['faflag'] = 1;
		}
		
		if ($scratch_code_flag){
			$fields['acctype'] = "1";
			$bFieldNumeric['acctype'] = 1;
		}
		
		$apiObj = new fsAPI();
		$result_update = $apiObj->addUser($username, $password1, $fields, $bFieldNumeric);
		$apiObj = null;

		// 20100503 - Check return value from new function
		// 20090402 - Add new return value for DB failure
		switch ($result_update) {
		case 0:
			$status = 10;
			break;
		case 2:
			$status = 2;
			break;
		case 1:
		default:
			$status = 0;
		}
	}
	//release COM object
	$settingobj=null;
	return $status;
}

// 20100504 - Account control and update when signing for free access
function FSProcessFreeAccessUser($username, $password1, $password2, $security, $free_access_flag, $free_access_plan)
{
	$fs_usr_table = fs_usr_table();

	// Check if account exists
	$qStr = "SELECT COUNT(*) as cnt FROM $fs_usr_table WHERE name='$username'";
	$qResult = db_query($qStr);

	if ($qResult == FALSE) {
		// DB error
		$create_result = 10;
	} else if (odbc_result($qResult, 'cnt') > 0) {
		// Check free access related attributes
		$qStr = "SELECT * FROM $fs_usr_table WHERE name='$username'";
		$qResult = db_query($qStr);

		if ($qResult == FALSE) {
			$create_result = 10;
		} else {
			$faFlag = odbc_result($qResult, 'faflag');

			if ($faFlag == null || $faFlag == 0) {
				// Account exists but not for free access, show error
				$create_result = 2;
			} else {
				$faRegTime = odbc_result($qResult, 'faregtime');

				if ($faRegTime == null || $faRegTime == '') {
					// Account exists for free access but never registers before, exit directly
					$create_result = 0;
				} else {
					$apiObj = new fsAPI();
					$tmpArray = $apiObj->checkUserStatus($username);

					if ($tmpArray['online_count'] > 0) {
						// Free access account has last login time and is currently online, exit directly
						$create_result = 0;
					} else {
						$bCheckSuspend		= 0;
						$create_result		= 0;
						$currTime			= strtotime('NOW');
						$actTime			= strtotime($faRegTime);
						$settingObj			= new COM('FSCONFIG.Cfgmgr') or die('fs_signup.php FSCONFIG.Cfgmgr Object cannot be created!');
						$free_access_option	= $settingObj->getKey('free_access_option', 'gateway');

						if ($free_access_option == null || $free_access_option == 0) {
							// One-off, check if still within free session
							$bCheckSuspend = 1;
						} elseif ($free_access_option == 1) {
							$free_access_reset_time = $settingObj->getKey('free_access_reset_time', 'gateway');
							$todayResetTime = strtotime(date('D M d', $currTime)." $free_access_reset_time:00 ".date('Y', $currTime));

							if ($currTime < $todayResetTime) {
								if ($actTime >= ($todayResetTime - 86400)) {
									// Not reach today's reset time but have yesterday's free session registered
									$bCheckSuspend = 1;
								}
							} elseif ($actTime >= $todayResetTime) {
								// Registered today's free session
								$bCheckSuspend = 1;
							}
						} else {
							$free_access_reset_minute = $settingObj->getKey('free_access_reset_minute', 'gateway');
							if (($currTime - $actTime) < ($free_access_reset_minute * 60)) {
								// Not reach next reset time
								$bCheckSuspend = 1;
							}
						}

						if ($bCheckSuspend) {
							$timeLeft	= odbc_result($qResult, 'timeleft');
							$eDate		= odbc_result($qResult, 'edate');
							$eMonth		= odbc_result($qResult, 'emonth');
							$eYear		= odbc_result($qResult, 'eyear');
							if (($timeLeft != null && (int)$timeLeft == 0) || ($eDate != null && strtotime($eDate) < $currTime) || ($eMonth != null && $eYear != null && mktime(0,0,0,(int)$eMonth+1,1,(int)$eYear) < $currTime)) {
								// At least one suspend condition fulfills
								$create_result = 12;
							} else // Account is not being suspended
								$create_result = 13;
						}
						$settingObj = null;
					}
					$apiObj = null;
				}
			}
		}
	} else {
		// No such account, create new one
		$create_result = fs_create_user($username, $password1, $password2, 0, $_SESSION['sess_patronsoft2'], $security, $free_access_flag, 0);
	}
	return $create_result;
}

//\\ Check user if it is expired self sign-up user
function deleteExpiredSSUUser($username){
	$q="SELECT edate, emailver FROM ".fs_usr_table()." where name='$username'";
	$result=db_query($q);
	
	if($result == false)
		return; // connection fail
	else{
		$edate = odbc_result($result, 'edate');
		$emailver = odbc_result($result, 'emailver');
		// account has expired before verifying --> Delete user
		if($emailver != "" || $emailver != 'email confirmed'){
			if(strtotime($edate) < time()){
				$q		= "Delete from ".fs_usr_table()." where name = '$username' and emailver = '$emailver'";
				$result	= db_query($q);
				return;
			}
		}
		return; // no delete need
	}
}

//$dbmsg='';
$wait_before_redirect=5;
$security = false;

$text_title=get_var('signup_form');

// 20100428 - Add receive free access mode flag, error checking
$username = isset($_POST['username'])? $_POST['username'] : '';
$password1 = isset($_POST['password1'])? $_POST['password1'] : '';
$password2 = isset($_POST['password2'])? $_POST['password2'] : '';
$emailVer = isset($_POST['emailVer'])? $_POST['emailVer'] : '';	//\\ >>> 222
//$dbmsg .= 'emailVer : '.$emailVer.'<br/>'; 
$success_url = isset($_POST['success_url'])? $_POST['success_url'] : '';
$failed_url = isset($_POST['failed_url'])? $_POST['failed_url'] : '';
$failed_url2 = isset($_POST['failed_url2'])? $_POST['failed_url2'] : '';
$free_access_flag = isset($_POST['free_access_flag'])? $_POST['free_access_flag'] : 0;
$scratch_code_flag = isset($_POST['scratch_code_flag'])? $_POST['scratch_code_flag'] : 0;


// 20100429 - Add 12: use up free access, skip case 13
// 20100412 - Add 11: session cookies disabled
// 20090402 - For database not available
$return_result_text[0]=get_var('signup_ok_header');
$return_result_text[1]=get_var('signup_problem_id_empty');
$return_result_text[2]=get_var('signup_problem_id_duplicate');
$return_result_text[3]=get_var('signup_problem_pwd_empty');  
$return_result_text[4]=get_var('signup_problem_pwd_mismatch'); 
$return_result_text[5]=get_var('signup_problem_signup_once'); 
$return_result_text[6]=get_var('signup_problem_signup_later'); 
$return_result_text[7]=get_var('signup_problem_no_mac'); 
$return_result_text[8]=get_var('signup_problem_field_empty');
$return_result_text[9]=get_var('signup_problem_security_code_mismatch'); 
$return_result_text[10]=get_var('signup_problem_db_unavailable');
$return_result_text[11] = get_var('signup_problem_session_cookies_disabled');
$return_result_text[12] = get_var('signup_problem_fa_used_up');
$return_result_text[13] = "";
$return_result_text[14] = get_var('signup_block_msg');

$error_message_header=get_var('signup_fail_header');
$error_message_footer=get_var('signup_fail_link');
$success_message_footer=get_var('signup_ok_link');
$settingobj = new COM("FSCONFIG.Cfgmgr") or die("fs_signup.php FSCONFIG.Cfgmgr Object cannot be created!");
$self_signup_not_show_form = $settingobj->getKey('self_signup_not_show_form', 'gateway');
$initial_credit=$settingobj->getKey( "self_sign_up_credit", "gateway");
$session_handling=$settingobj->getKey( "session_handling", "gateway");
$redirect_address = $settingobj->getKey( 'redirect_address', 'gateway');
//self_sign_up attributes

// 20090325 - Add checking if show domain name or IP
$show_domain_URL = $settingobj->getKey('show_domain_URL', 'gateway');
$loginform = fs_urlhead();

//\\ 20130402 >>> 222 - E-mail confirmation response path
$email_response_link = $loginform;

$self_sign_up_option=$settingobj->getKey( "self_sign_up_option", "gateway");
$redirect_url = $settingobj->getKey( 'self_sign_up_redirect', 'gateway');

//Linus 20131029
$initial_plan = $settingobj->getKey( "self_sign_up_plan", "gateway");

$captcha_check = $settingobj->getKey('self_sign_up_captcha_check', 'gateway');
if ($captcha_check == 'on' && isset($_POST['security_code']))
	$security_code=$_POST['security_code'];

//try to get ip use php if $sess_patronsoft2 is null
//this will only happen when the user directly access to signup_form.php or login_form.php
if ($session_handling == "1" && $_SESSION['sess_patronsoft2'] == "") 
	//flip ip address and convert it into long format
	$_SESSION['sess_patronsoft2'] = ip2long(join('.', array_reverse( explode('.', $_SERVER['REMOTE_ADDR']) ) ));  

//$isUpdate = false;

$arr = array('01', '02', '03', '04', '05', '06', '07', '08', '09', '10');

foreach ($arr as $value) {
	${"signup$value"."_not_empty"} = $settingobj->getKey( "ReqSignUp$value", "lang");
}

$free_access_mode = $settingobj->getKey('free_access_mode', 'gateway');
// 20100505 - Obtain plan for Free Access
$free_access_plan = $settingobj->getKey('free_access_plan', 'gateway');

$scratch_login = (strtolower($settingobj->getKey('scratch_login', 'gateway') == 'on'))? 'true' : 'false';
$username_plus_scratch_login = (strtolower($settingobj->getKey('username_plus_scratch_login', 'gateway') == 'on'))? 'true' : 'false';

if ($scratch_login == "true") {
	$scratch_code_flag = 1;
}
else if ($username_plus_scratch_login == "false" && $scratch_code_flag == 1){ // mean: username / password login modes
	$scratch_code_flag = 0;
}

//\\ 20130402 >>> 222 - E-mail confirmation data
//\\ 20130606 >>> 222.1 - New process for sending email
$email_confirmation = $settingobj->getKey( "self_sign_up_email_verification", "gateway");
$email_grace_min = $settingobj->getKey( "self_sign_up_grace_min", "gateway");
$cartRedirection = $settingobj->getKey( "self_sign_up_ev_cart_redirect", "gateway");
//$dbmsg .= 'email_confirmation = '.$email_confirmation.'<br/>';
//$dbmsg .= 'email_grace_min = '.$email_grace_min.'<br/>';

//release object
$settingobj=null;

$emptyFieldError = 0;

foreach ($arr as $value) {
    if (isset(${"signup$value"})) {
        if (${"signup$value"} == "" && ${"signup$value"."_not_empty"} == 'on'){
            $emptyFieldError = 1;
        }
    }
    if( $emptyFieldError )
        break;
}

if( $emptyFieldError )
{
	$create_result = 8;
	$form_element="error_code";
	$scriptInput = '';
	$element_value = 8;
    $status_message = "<span class=\"failloginspan\">".$error_message_header."</span><br><br>";
    $status_message.="<span class=\"textspan\">".$return_result_text[8]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
    $submit_url = $failed_url;
}
else{
	// 20100428 - Check free access flag if new login account is required
	if ($free_access_flag) {
		if ($session_handling==0){
			$username = isset($_SESSION['sess_patronsoft2'])? make_mac_name($_SESSION['sess_patronsoft2']) : '';
		} else{
			$username = isset($_SESSION['sess_patronsoft2'])? make_ip_name($_SESSION['sess_patronsoft2']) : '';	
		}
		
		$password1 = 'TRIAL';
		$password2 = 'TRIAL';
		$_SESSION['free_access_flag'] = 1;

		if (!isset($security_code) && $captcha_check == 'off') {
			$security = true;
		} elseif (isset($_SESSION['session_security_code_fa']) && isset($_POST['security_code']) && $_SESSION['session_security_code_fa'] == $security_code) {
			$security = true;
		}
	}
	else {
		if ($scratch_code_flag){
			$password1 = $username;
			$password2 = $username;
		}
		
		// the captcha check is off
		if (!isset($security_code) && $captcha_check == 'off' ){
			$security = true;
		}
		//Compare security code 
		else if (isset($_SESSION['session_security_code_su']) && isset($_POST['security_code'])){
			if ($_SESSION['session_security_code_su'] == $security_code ){
				$security = true;
			}
		}
	}

	// double check option
	if ($free_access_flag){
		if (!strcasecmp($free_access_mode, 'on') == 0) {
			// option not set
			$create_result = 14;
		}
	}
	else{
		if ($self_signup_not_show_form){
			// option not set
			$create_result = 14;
		}
	}

	if (!isset($create_result)){
		if (isset($username) && $username!=''){	// checking
			$pos = strpos($username, " ");
			if ($pos === false){}
			else
				$create_result = 10;	// treat as db error
		}
	}

	if (!isset($create_result)){
		if (!isset($_SESSION['sess_patronsoft2']))
			$_SESSION['sess_patronsoft2'] = "";

		// Delete expired self sign-up user with email verification and new self sign-up username
		deleteExpiredSSUUser($username);

		// 20100428 - Add free_access_flag
		if ($free_access_flag) {
			if ($_SESSION['sess_patronsoft2'] == '')
				$create_result = 11;
			elseif ($security == false)
				$create_result = 9;
			else
				$create_result = FSProcessFreeAccessUser($username, $password1, $password2, $security, $free_access_flag, $free_access_plan);
		}
		else
			$create_result = fs_create_user($username, $password1, $password2, $initial_credit, $_SESSION['sess_patronsoft2'], $security, $free_access_flag, $scratch_code_flag);
	}

	//$dbmsg .= 'Before send mail : create_result = '.$create_result.' , email_confirmation = '.$email_confirmation.'<br/>';
	if ((isset($create_result) && $create_result == 0) && $email_confirmation==1){
		$sendMail = true;
		$print_err_log = false;
		$export_file = 'email_confirmation.log';
		$output = "";
			
		$curr_time = time();
		if($cartRedirection=='1')
			$en_str = base64_encode("uid=".$username."=".$password1);
		else
			$en_str = base64_encode("uid=".$username."=");
		$_SESSION['ssuev_link_content']=$en_str;
		$email_response_link .= "email_callback.php?code=$en_str";
		$to = array();
		$to[0][0] = "to";
		$to[0][1] = $emailVer;
		$to[0][2] = $username;
			
		// hard code
		$filename = "..\\authserv\\email_verification_format.eml";
		$handle = fopen($filename, "rb");
		$contents = fread($handle, filesize($filename));
		fclose($handle);
			
		// replace the tag
		/*
			%confirm_link%
			%username%
		*/
		$count = 0;
		$contents = str_ireplace("%confirm_link%", $email_response_link, $contents, $count);
		// checking is it contain link tag
		//$dbmsg .= 'contents count = '.$count.'<br/>';
		if ($count <= 0){

			$sendMail = false;
			$print_err_log = true;

			$output = date("D M d H:i:s Y")." \t do not send email to user (since email sampe (email_verification_format.eml) do not contain any link tag)\r\n";
		}
		$contents = str_ireplace("%username%", $username, $contents); 
			
		// divide content
		$pos = stripos($contents, "\r\n\r\n");
			
		if ($pos === false){
			// error
		}
			
		$org_header = substr($contents, 0, $pos);
			
		$message_body = strstr($contents, "<!DOCTYPE");	// Hardcode
			
		// get data from content
		$pos_subject_start = stripos($org_header, "Subject: ");
		$pos_subject_end = stripos($org_header, "\r\n", $pos_subject_start);
		$message_subject = substr($org_header, $pos_subject_start + strlen("Subject: "),$pos_subject_end-$pos_subject_start - strlen("Subject: "));

		$pos_to_start = stripos($org_header, "To: ");
		$pos_to_end = stripos($org_header, "\r\n", $pos_to_start);
		$message_to = substr($org_header, $pos_to_start + strlen("To: "),$pos_to_end-$pos_to_start - strlen("To: "));

		//$dbmsg .= 'Mail Info - To : ['.$to.']<br/>';
		//$dbmsg .= 'Mail Info - Subject : ['.$message_subject.']<br/>';
		//$dbmsg .= 'Mail Info - Body : ['.$message_body.']<br/>';
		//$dbmsg .= 'sendMail = './/$dbmsg.'<br/>';
		if ($sendMail){
			$mail_sent = sys_mail( $to, $message_subject, $message_body, setVerifyMail());
			if ($mail_sent!="0"){
				$print_err_log = true;
				$output = date("D M d H:i:s Y")."\t Email Error : $mail_sent\r\n";
			}
		}
		if ($print_err_log){

			if (is_file("..\\log\\".$export_file) == FALSE)
				touch ("..\\log\\".$export_file);
			$fileHandler = fopen ("..\\log\\".$export_file, 'a');
			fwrite ($fileHandler, $output);
			fclose ($fileHandler);
		}
	}
	//\\ End Process >>> 222

	// username, 1st password, 2nd password, timeleft assigned
	// update the user table with plan setting
	if ((isset($create_result) && $create_result == 0) && $email_confirmation==0){
		// 20100505 - Check if Free Access mode
		if ($free_access_flag) {
			if ($free_access_plan != '') {
				$q = fs_usr_plan_update_query($free_access_plan, $username, $free_access_flag, false);
				if ($q != null) {
					$result = db_query($q);
					if ($result == FALSE)
						$create_result = 10;
				}
			}
		} elseif ($initial_plan != "") {
		
			//Linus 20131108
			$q = fs_usr_plan_update_query($initial_plan, $username, $free_access_flag, $scratch_code_flag);
					
			// 20090403 - Improve error handling
			if ($q != null) {
					$result = db_query($q);
				if ($result == FALSE)
					$create_result = 10;
			}
		} 
	}

	// 20100505 - Back to normal flow for Free Access
	if ($create_result == 13)
		$create_result = 0;

	// update the user table with extra information field
	if ($create_result == 0) {
		$q = "UPDATE ".fs_usr_table()." SET";

		foreach ($arr as $value)
			if (isset(${"signup$value"}))
					$q .= " SIGNUP$value = '".${"signup$value"}."',";

	//	$q = substr($q, 0, strlen($q) - 1);  //trim the ending comma

		if($emailVer!='')
			$q .= " TIMELEFT = NULL, STARTMOD = 0, SDATE = '".date('D M d H:i:s Y')."', EMAILVER = '".$emailVer."', EMINUTES = ".$email_grace_min.",";

		$q .= " REQSIGNUP = NULL WHERE NAME = '$username'";
		//$dbmsg .= 'User Update SQL : '.$q;
		$result = db_query($q);

		// 20090403 - Improve error handling
		if ($result == FALSE)
			$create_result = 10;
	}

	//determine self_sign_up_option
	// 20100429 - Add default redirection for free access accounts
	// 20090323 - Redirect to sign-up form for no IP/MAC
	if (!isset($_SESSION['sess_patronsoft2']) || $_SESSION['sess_patronsoft2'] == '') {
		$redirect_url = $failed_url;
		
		if ($scratch_code_flag == 1 || (isset($fa_in_sc_flag) && $fa_in_sc_flag == 1))
			$redirect_url .= "?sc=1";
		
	} elseif ($free_access_flag)
		$redirect_url = 'fs_login.php';
	elseif ($self_sign_up_option == 0)
		$redirect_url="";
	else if ($self_sign_up_option == 1) {
		$redirect_url=$loginform;
		$_SESSION['sess_loginPage'] = true;
	}
	else if ($self_sign_up_option == 2)
		$redirect_url="cart.php?username=$username";
	else if ($self_sign_up_option == 4)
		$redirect_url="login_form.php";
	else if ($self_sign_up_option == 5)
		$redirect_url="login_form.php?code=".rawurlencode(encrypt($username.'|'.$password1));
		
	$success_url = ($redirect_url=="")?"login_form.php":$redirect_url;
	$failed_url.="?error_code=".$create_result;
	$failed_url2.="?error_code=".$create_result;

	if ($scratch_code_flag == 1 || (isset($fa_in_sc_flag) && $fa_in_sc_flag == 1)){
		$failed_url .= "&sc=1";
		$failed_url2 .= "&sc=1";
	}

	$status_message = "<span class=\"failloginspan\">".$error_message_header."</span><br><br>";

	if ($create_result == 0){
		// 20090325 - Check session variable
		if (!isset($_SESSION['sess_patronsoft2']) || $_SESSION['sess_patronsoft2'] == '')
			$status_message ="<span class=\"textspan\">".$return_result_text[0]."</span><br><a class=\"freelink\" href=\"$failed_url\">".$success_message_footer."</a><br>";
		else
			$status_message ="<span class=\"textspan\">".$return_result_text[0]."</span><br><a class=\"freelink\" href=\"$success_url\">".$success_message_footer."</a><br>";
	}
	elseif ($create_result == 1)																							
		$status_message.="<span class=\"textspan\">".$return_result_text[1]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 2)
		$status_message.="<span class=\"textspan\">".$return_result_text[2]."</span>&nbsp;&nbsp;<span class=\"boldtextspan\">".$username.".</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 3)
		$status_message.="<span class=\"textspan\">".$return_result_text[3]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 4)
		$status_message.="<span class=\"textspan\">".$return_result_text[4]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 5)
		$status_message.="<span class=\"textspan\">".$return_result_text[5]."</span><br><a class=\"freelink\" href=".$failed_url2.">".$error_message_footer."</a><br>";
	elseif ($create_result == 6)
		$status_message.="<span class=\"textspan\">".$return_result_text[6]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 7)	// 20090325 - Redirect to login page for session IP/MAC
		$status_message .= "<span class=\"textspan\">".$return_result_text[7]."</span><br><a class=\"freelink\" href=".$loginform.">".$error_message_footer."</a><br>";
	elseif ($create_result == 8)
		$status_message.="<span class=\"textspan\">".$return_result_text[8]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 9)
		$status_message.="<span class=\"textspan\">".$return_result_text[9]."</span><br><a class=\"freelink\" href=".$failed_url.">".$error_message_footer."</a><br>";
	elseif ($create_result == 10)	// 20090403 - DB not available
		$status_message .= '<span class="textspan">'.$return_result_text[10].'</span><br><a class="freelink" href='.$failed_url.'>'.$error_message_footer.'</a><br>';
	elseif ($create_result == 11)	// 20100412 - Session cookies disabled
		$status_message .= '<span class="textspan">'.$return_result_text[11].'</span><br><a class="freelink" href='.$failed_url.'>'.$error_message_footer.'</a><br>';
	elseif ($create_result == 12)	// 20100429 - Free access is used up
		$status_message .= '<span class="textspan">'.$return_result_text[12].'</span><br><a class="freelink" href='.$failed_url.'>'.$success_message_footer.'</a><br>';
	elseif ($create_result == 14)
		$status_message .= '<span class="textspan">'.$return_result_text[14].'</span><br><a class="freelink" href='.$failed_url.'>'.$success_message_footer.'</a><br>';

	// 20100507 - Close unnecessary IB popup
	$scriptInput = '';
	if ($free_access_flag && $create_result != 0) {
		$scriptInput .= "
			popupWin = window.open('', 'firstspotInfoBox', '');
			if (popupWin) {
				popupWin.close();
			}";
	}

	if ($create_result == 0) {
		$submit_url=$success_url."?username=".$username;
		$form_element="username";
		$element_value=$username;
		if(!session_id())
			session_start();

		$_SESSION['session_username']=$username;
		$_SESSION['cart_url'] = "cart.php?username=$username";

		// 20100503 - Save login information as session variables for free access account
		if ($free_access_flag) {
			$_SESSION['free_access'] = 1;
			$_SESSION['session_password'] = $password1;
			$_SESSION['cart_url'] = 'signup_form.php';
			
			if ($scratch_code_flag == 1 || (isset($fa_in_sc_flag) && $fa_in_sc_flag == 1))
				$_SESSION['cart_url'] .= "?sc=1";
		}
	} else {
		$submit_url=$failed_url;
		$form_element="error_code";
		$element_value=$create_result;
	}
}
// 20100505 - Assign new tag J_FSSIGNUP_SCRIPT
// 20080403 - Collect dynamic HTML content for layout
$smarty = new SmartyConnect;
$smarty->assign('L_FSSIGNUP_CHARSET', metaCharset());
$refreshStr = '';
if ($create_result == 1 || $create_result == 2 || $create_result == 3 || $create_result == 4 || $create_result == 8 || $create_result == 9)
	$refreshStr = "<meta http-equiv=\"refresh\" content=\"$wait_before_redirect;url=$failed_url\">";
elseif ($create_result == 0) {
	// 20100503 - Set auto-redirect for free access case
	if ((isset($free_access_flag) && $free_access_flag) || $self_sign_up_option != 0)
		$refreshStr = "<meta http-equiv=\"refresh\" content=\"$wait_before_redirect;url=$redirect_url\">";
}
$smarty->assign('L_FSSIGNUP_REFRESH', $refreshStr);
$smarty->assign('L_FSSIGNUP_TITLE', $text_title);
$smarty->assign('FSSIGNUP_SUBMIT_URL', $submit_url);
$smarty->assign('FSSIGNUP_FORM_ELEMENT', $form_element);
$smarty->assign('FSSIGNUP_ELEMENT_VALUE', $element_value);
$smarty->assign('L_FSSIGNUP_STATUS_MSG', $status_message);
$smarty->assign('J_COMMON', $j_common);
$smarty->assign('J_FSSIGNUP_SCRIPT', $scriptInput);
//$smarty->assign('DEBUG_MSG', $dbmsg);	//\\=

// 20080403 - Move layout content and include the file here
$smarty->display('fs_signup_body.tpl');

?>
